@@ -2,7 +2,7 @@ from enum import Enum
 
 from pydantic import BaseModel
 
-from switcore.ui.element_components import Subtext, Tag, StaticAction
+from switcore.ui.element_components import SubText, Tag, StaticAction
 from switcore.ui.image import Image
 from switcore.ui.text_paragraph import TextParagraph
 
@@ -32,7 +32,7 @@ class MetadataItem(BaseModel):
 
 class TextSection(BaseModel):
     text: TextParagraph
-    metadata_items: list[Subtext | Image | Tag] | None
+    metadata_items: list[SubText | Image | Tag] | None
 
 
 class VerticalAlignmentTypes(str, Enum):
