@@ -25,27 +25,27 @@ class Tag(BaseModel):
     style: Style | None = None
 
 
-class Subtext(BaseModel):
+class SubText(BaseModel):
     type: str = "subtext"
     content: str
 
 
 class OpenOauthPopup(BaseModel):
-    type: str = "open_oauth_popup"
+    action_type: str = "open_oauth_popup"
     link_url: str
 
 
 class OpenLink(BaseModel):
-    type: str = "open_link"
+    action_type: str = "open_link"
     link_url: str
 
 
 class CloseView(BaseModel):
-    type: str = "close_view"
+    action_type: str = "close_view"
 
 
 class ClipboardCopy(BaseModel):
-    type: str = "clipboard_copy"
+    action_type: str = "clipboard_copy"
     content: str
 
 
