@@ -7,6 +7,6 @@ class Tabs(BaseModel):
     """
         An element representing an array of tabs.
     """
-    type = "tabs"
+    type: str = "tabs"
     tabs: list[SelectItem]
     value: str
